# Changelog

All notable changes to this project will be documented in this file.

## [0.2.3] - 2025-02-09

### 🚀 Features

- Add option to specify tag prefix in version command (#111)

### 📚 Documentation

- Create proper README.md (#106)
- Add python 3.13 classifier (#107)
- Lint and format all Markdown files (#108)

### ⚙️ Miscellaneous Tasks

- Rename check jobs (#110)

## [0.2.2] - 2024-12-20

### 🚀 Features

- Allow specifying rev range in check command (#105)

### 📚 Documentation

- Add nosec comment to breaking change regex (#99)

### 🧪 Testing

- Add test for second line being empty (#100)
- Add test for message not being bytes (#101)
- Remove unnecessary print statement (#104)

### ⚙️ Miscellaneous Tasks

- Fix changelog generation by full checkout (#96)
- Fix run of bandit by using correct target (#97)
- Run bandit on tests (#98)
- Audit dependencies after installation (#102)
- Add merge group to check-code workflows to enable merge queues (#103)

## [0.2.1] - 2024-12-17

### 🚀 Features

- Use special handling for development 0.x.x versions (#90)

### 🚜 Refactor

- Use rev range in get_next_version() (#92)

### 🧪 Testing

- Format test files (#93)

### ⚙️ Miscellaneous Tasks

- Add semantic release workflow (#87)
- Run Semantic Release on Check Code completed (#88)
- Add release concurrency groups (#89)
- Check code format instead of reformatting (#94)
- Fix semantic release workflow by adding actions write permission (#95)

## [0.2.0] - 2024-12-16

### 🚜 Refactor

- Sort imports (#66)
- Adhere to PEP8 naming (#67)
- Use frozenset for commit types (#69)
- Simplify breaking change footer detection (#75)
- Parse git commit using classmethod (#76)
- Move git repo parsing to main (#77)
- Rename module _check to _commit (#78)
- Delete deprecated flag parameter (#82)
- Define repo in main (#79)
- [**breaking**] Do not use __main__.py (#86)

### 📚 Documentation

- Add code of conduct (#73)
- Fix name of code of conduct file (#74)

### 🧪 Testing

- Add more valid messages (#63)
- Add version tests (#80)
- *(version)* Add test that only parent commits are used (#81)
- Add pytest-cov for checking test coverage (#83)
- Add test for check commits in Git repo (#84)

### ⚙️ Miscellaneous Tasks

- Do not log pyproject.toml content (#61)
- *(pr-title-check)* Do not fail PR title check when special chars in title (#64)
- *(release)* Validate version format early (#62)
- Use more specific ruff section in pyproject (#68)
- Add more ruff rules (#70)
- Run code checks in a single job (#71)
- Use python matrix (#72)
- More pytest-cov to dev deps (#85)

## [0.1.1] - 2024-12-14

### 🐛 Bug Fixes

- Check command now actually checks git history (#59)

### ⚙️ Miscellaneous Tasks

- Check PR title on PR edit (#60)

## [0.1.0] - 2024-12-14

### 🚀 Features

- Add check function (#2)
- Add --from-stdin option (#7)
- Check if second line is empty (#31)
- [**breaking**] Add version command (#33)
- Add console script (#38)

### 🐛 Bug Fixes

- Do not fail on multiline commit messages (#5)
- Raise TypeError when commit summary is bytes (#13)
- Do not fail on valid multiline message from stdin (#26)

### 🚜 Refactor

- [**breaking**] Rename check to _check_git (#6)
- Add type hints (#11)
- Import from correct module (#12)
- [**breaking**] Rename module (#25)
- Delete pointless statement (#32)
- Convert functions into classmethods (#40)
- Yield parsed commits (#41)
- Check module (#39)
- Rename public version functions (#42)

### 📚 Documentation

- Add README.md (#1)

### 🧪 Testing

- Change data format to YAML (#43)

### ⚙️ Miscellaneous Tasks

- Initial empty commit
- Add .gitignore (#3)
- Run tests on push (#4)
- Rename workflow (#8)
- Check commits via aserehe (#9)
- Check PR title is conventional (#10)
- Run mypy (#14)
- Add MIT license (#27)
- Add trove classifiers (#28)
- Add repo url to pyproject.toml (#29)
- Fix commit check on main (#37)
- Use narrower import-untyped mypy comment (#44)
- Use uv dependency manager (#45)
- Update uv.lock with python version (#46)
- Fix repository URL specification (#47)
- Check uv.lock during setup (#48)
- Use ruff format instead of black (#49)
- Upgrade dev dependencies (#50)
- Upgrade minimal version of dependencies (#51)
- Run security check with bandit (#52)
- Reference license file in pyproject.toml (#53)
- Add release on dispatch (#54)
- Fix release by adding id-token write permission (#55)
- Add release environment (#56)
- Validate version format (#57)
- Change environment from release to production (#58)

<!-- generated by git-cliff -->
